@@ -111,3 +111,14 @@ class ClientModel(ABC):
                     pass
         self.__setitem__('total', total)
 
+    def set_unit(self, key, value):
+        ''' set the unit for the metric '''
+        self.dict['units'][key] = value
+
+    def delete_unit(self, key):
+        ''' delete the unit for the metric '''
+        del self.dict['units'][key]
+
+    def get_unit(self, key):
+        ''' get the unit for the metric '''
+        del self.dict['units'][key]
